@@ -683,14 +683,14 @@ sen_index_create(const char *path, int key_size,
       strcpy(buffer, path);
       strcat(buffer, ".SEN.i");
       if ((i->inv = sen_inv_create(buffer, i->lexicon, initial_n_segments))) {
-        if ((flags & SEN_INDEX_WITH_STORE)) {
+        if ((flags & SEN_INDEX_WITH_VGRAM)) {
           strcpy(buffer, path);
           strcat(buffer, ".SEN.v");
-          i->store= sen_store_create(buffer);
+          i->vgram= sen_vgram_create(buffer);
         } else {
-          i->store = NULL;
+          i->vgram = NULL;
         }
-        if (!(flags & SEN_INDEX_WITH_STORE) || i->store) {
+        if (!(flags & SEN_INDEX_WITH_VGRAM) || i->vgram) {
           SEN_LOG(sen_log_notice, "index created (%s) flags=%x", path, i->lexicon->flags);
           return i;
         }
@@ -726,14 +726,14 @@ sen_index_open(const char *path)
       strcpy(buffer, path);
       strcat(buffer, ".SEN.i");
       if ((i->inv = sen_inv_open(buffer, i->lexicon))) {
-        if ((i->lexicon->flags & SEN_INDEX_WITH_STORE)) {
+        if ((i->lexicon->flags & SEN_INDEX_WITH_VGRAM)) {
           strcpy(buffer, path);
           strcat(buffer, ".SEN.v");
-          i->store = sen_store_open(buffer);
+          i->vgram = sen_vgram_open(buffer);
         } else {
-          i->store = NULL;
+          i->vgram = NULL;
         }
-        if(!(i->lexicon->flags & SEN_INDEX_WITH_STORE) || i->store) {
+        if(!(i->lexicon->flags & SEN_INDEX_WITH_VGRAM) || i->vgram) {
           SEN_LOG(sen_log_notice, "index opened (%p:%s) flags=%x", i, path, i->lexicon->flags);
           return i;
         }
@@ -775,14 +775,14 @@ sen_index_create_with_keys(const char *path, sen_sym *keys,
     strcpy(buffer, path);
     strcat(buffer, ".SEN.i");
     if ((i->inv = sen_inv_create(buffer, i->lexicon, initial_n_segments))) {
-      if ((flags & SEN_INDEX_WITH_STORE)) {
+      if ((flags & SEN_INDEX_WITH_VGRAM)) {
         strcpy(buffer, path);
         strcat(buffer, ".SEN.v");
-        i->store= sen_store_create(buffer);
+        i->vgram= sen_vgram_create(buffer);
       } else {
-        i->store = NULL;
+        i->vgram = NULL;
       }
-      if (!(flags & SEN_INDEX_WITH_STORE) || i->store) {
+      if (!(flags & SEN_INDEX_WITH_VGRAM) || i->vgram) {
         SEN_LOG(sen_log_notice, "index created (%s) flags=%x", path, i->lexicon->flags);
         return i;
       }
@@ -817,14 +817,14 @@ sen_index_open_with_keys(const char *path, sen_sym *keys)
     strcpy(buffer, path);
     strcat(buffer, ".SEN.i");
     if ((i->inv = sen_inv_open(buffer, i->lexicon))) {
-      if ((i->lexicon->flags & SEN_INDEX_WITH_STORE)) {
+      if ((i->lexicon->flags & SEN_INDEX_WITH_VGRAM)) {
         strcpy(buffer, path);
         strcat(buffer, ".SEN.v");
-        i->store = sen_store_open(buffer);
+        i->vgram = sen_vgram_open(buffer);
       } else {
-        i->store = NULL;
+        i->vgram = NULL;
       }
-      if(!(i->lexicon->flags & SEN_INDEX_WITH_STORE) || i->store) {
+      if(!(i->lexicon->flags & SEN_INDEX_WITH_VGRAM) || i->vgram) {
         SEN_LOG(sen_log_notice, "index opened (%p:%s) flags=%x", i, path, i->lexicon->flags);
         return i;
       }
@@ -843,7 +843,7 @@ sen_index_close(sen_index *i)
   if (!i->foreign_keyp) { sen_sym_close(i->keys); }
   sen_sym_close(i->lexicon);
   sen_inv_close(i->inv);
-  if (i->store) { sen_store_close(i->store); }
+  if (i->vgram) { sen_vgram_close(i->vgram); }
   SEN_FREE(i);
   return sen_success;
 }
@@ -862,7 +862,7 @@ sen_index_remove(const char *path)
   snprintf(buffer, PATH_MAX, "%s.SEN.l", path);
   sen_sym_remove(buffer);
   snprintf(buffer, PATH_MAX, "%s.SEN.v", path);
-  sen_io_remove(buffer); // sen_store_remove
+  sen_io_remove(buffer); // sen_vgram_remove
   return sen_success;
 }
 
@@ -997,13 +997,13 @@ index_add(sen_index *i, const void *key, const char *value, size_t value_len)
   sen_inv_updspec **u;
   sen_id rid, tid, *tp;
   sen_rc r, rc = sen_success;
-  sen_store_buf *sbuf = NULL;
+  sen_vgram_buf *sbuf = NULL;
   //  sen_log("add > (%x:%x)", i, key);
   if (!(rid = sen_sym_get(i->keys, key))) { return sen_invalid_argument; }
   if (!(lex = sen_lex_open(i->lexicon, value, value_len, SEN_LEX_ADD|SEN_LEX_UPD))) {
     return sen_memory_exhausted;
   }
-  if (i->store) { sbuf = sen_store_buf_open(value_len); }
+  if (i->vgram) { sbuf = sen_vgram_buf_open(value_len); }
   h = sen_set_open(sizeof(sen_id), sizeof(sen_inv_updspec *), 0);
   if (!h) {
     SEN_LOG(sen_log_alert, "sen_set_open on index_add failed !");
@@ -1024,11 +1024,11 @@ index_add(sen_index *i, const void *key, const char *value, size_t value_len)
         SEN_LOG(sen_log_error, "sen_inv_updspec_add on index_add failed!");
         goto exit;
       }
-      if (sbuf) { sen_store_buf_add(sbuf, tid); }
+      if (sbuf) { sen_vgram_buf_add(sbuf, tid); }
     }
   }
   sen_lex_close(lex);
-  if (sbuf) { sen_store_update(i->store, rid, sbuf, h); }
+  if (sbuf) { sen_vgram_update(i->vgram, rid, sbuf, h); }
   c = sen_set_cursor_open(h);
   SEN_ASSERT(c);
 /*
@@ -1124,7 +1124,7 @@ sen_index_upd(sen_index *i, const void *key,
   sen_rc rc;
   if (!i || !key) { SEN_LOG(sen_log_warning, "sen_index_upd: invalid argument"); return sen_invalid_argument; }
   if ((rc = sen_index_lock(i, -1))) {
-    SEN_LOG(sen_log_error, "sen_index_upd: index lock failed");
+    SEN_LOG(sen_log_crit, "sen_index_upd: index lock failed");
     return rc;
   }
   // sen_log("index_upd %p %x > '%s'->'%s'", i, key, oldvalue, newvalue);
