@@ -64,7 +64,7 @@ struct _sen_vse {
 
 sen_vse *sen_vse_create(const char *path, unsigned int max_element_size);
 sen_vse *sen_vse_open(const char *path);
-sen_rc sen_vse_info(sen_vse *vse, unsigned int *max_element_size, sen_id *curr_max);
+sen_rc sen_vse_info(sen_vse *vse, unsigned int *max_element_size);
 sen_rc sen_vse_close(sen_vse *vse);
 sen_rc sen_vse_remove(const char *path);
 sen_rc sen_vse_put(sen_vse *vse, sen_id id, const void *value, int value_len, int flags);
@@ -74,43 +74,95 @@ const void *sen_vse_ref(sen_vse *vse, sen_id id, int *value_len);
 sen_rc sen_vse_unref(sen_vse *vse, sen_id id);
 
 int sen_vse_size(sen_vse *vse, sen_id id);
-sen_vse_einfo *sen_vse_alloc(sen_vse *vse, int element_size, void **value);
+sen_rc sen_vse_alloc(sen_vse *vse, int element_size, sen_vse_einfo *einfo, void **value);
 sen_rc sen_vse_replace(sen_vse *vse, sen_id id, sen_vse_einfo *ei);
 
+/**** store ****/
+
+typedef struct _sen_store sen_store;
+typedef struct _sen_class sen_class;
+typedef struct _sen_obj sen_obj;
+typedef struct _sen_slot sen_slot;
+typedef struct _sen_class_spec sen_class_spec;
+typedef struct _sen_slot_spec sen_slot_spec;
+
+struct _sen_store {
+  sen_sym *keys;
+  sen_vse *values;
+};
+
+struct _sen_class {
+  sen_sym *keys;
+};
+
+struct _sen_obj {
+  sen_class *class;
+  sen_id id;
+  void *value;
+  int size;
+};
+
+struct _sen_slot {
+  char type;
+  sen_class *class;
+  sen_fse *fse;
+  sen_vse *vse;
+};
+
+sen_store *sen_store_create(const char *path, int flags, sen_encoding encoding);
+sen_store *sen_store_open(const char *path);
+sen_rc sen_store_close(sen_store *s);
+
+sen_class *sen_class_create(sen_store *s, const char *name, const char *spec);
+sen_class *sen_class_open(sen_store *s, const char *name);
+sen_rc sen_class_close(sen_class *);
+
+sen_rc sen_class_at(sen_class *c, void *key, int flags, sen_obj *res);
+sen_rc sen_obj_at(sen_obj *o, sen_slot *slot, sen_obj *res);
+sen_rc sen_obj_update(sen_obj *o, sen_slot *slot, sen_obj *value);
+int sen_obj_key(sen_obj *o, void *keybuf, int buf_size);
+
+#define SEN_OBJ2VALUE(o,v,s) (v = (o)->value, s = (o)->size)
+#define SEN_VALUE2OBJ(o,v,s) ((o)->value = v, (o)->size = s)
+
+sen_slot *sen_slot_create(sen_store *s, const char *name, const char *spec);
+sen_slot *sen_slot_open(sen_store *s, const char *name);
+sen_rc sen_slot_close(sen_slot *);
+
 /**** vgram ****/
 
-typedef struct _sen_store_vnode
+typedef struct _sen_vgram_vnode
 {
-  struct _sen_store_vnode *car;
-  struct _sen_store_vnode *cdr;
+  struct _sen_vgram_vnode *car;
+  struct _sen_vgram_vnode *cdr;
   sen_id tid;
   sen_id vid;
   int freq;
   int len;
-} sen_store_vnode;
+} sen_vgram_vnode;
 
-struct _sen_store {
+struct _sen_vgram {
   sen_sym *vgram;
 };
 
-struct _sen_store_buf {
+struct _sen_vgram_buf {
   size_t len;
   sen_id *tvs;
   sen_id *tvp;
   sen_id *tve;
-  sen_store_vnode *vps;
-  sen_store_vnode *vpp;
-  sen_store_vnode *vpe;
+  sen_vgram_vnode *vps;
+  sen_vgram_vnode *vpp;
+  sen_vgram_vnode *vpe;
 };
 
-sen_store *sen_store_create(const char *path);
-sen_store *sen_store_open(const char *path);
-sen_rc sen_store_close(sen_store *store);
-sen_rc sen_store_update(sen_store *store, sen_id rid, sen_store_buf *b, sen_set *terms);
+sen_vgram *sen_vgram_create(const char *path);
+sen_vgram *sen_vgram_open(const char *path);
+sen_rc sen_vgram_close(sen_vgram *vgram);
+sen_rc sen_vgram_update(sen_vgram *vgram, sen_id rid, sen_vgram_buf *b, sen_set *terms);
 
-sen_store_buf *sen_store_buf_open(size_t len);
-sen_rc sen_store_buf_add(sen_store_buf *b, sen_id tid);
-sen_rc sen_store_buf_close(sen_store_buf *b);
+sen_vgram_buf *sen_vgram_buf_open(size_t len);
+sen_rc sen_vgram_buf_add(sen_vgram_buf *b, sen_id tid);
+sen_rc sen_vgram_buf_close(sen_vgram_buf *b);
 
 #ifdef __cplusplus
 }
