@@ -67,7 +67,7 @@ struct sen_sym_header {
   uint16_t keyarray[SEN_SYM_MAX_SEGMENT];
   uint16_t patarray[SEN_SYM_MAX_SEGMENT];
   uint16_t sisarray[SEN_SYM_MAX_SEGMENT];
-  syn_sym_delinfo delinfos[SEN_SYM_NDELINFOS];
+  sen_sym_delinfo delinfos[SEN_SYM_NDELINFOS];
   sen_id garbages[(SEN_SYM_MAX_KEY_LENGTH + 1) / 8];
 };
 
@@ -344,11 +344,11 @@ pat_node_set_key(sen_sym *sym, pat_node *n, const uint8_t *key, unsigned int len
 #define SET_DL_ST(x,v) ((x)->bitfield = ((x)->bitfield & ~DL_STMASK) | ((v) & DL_STMASK))
 #define SET_DL_SH(x,v) ((x)->bitfield = ((x)->bitfield & ~DL_SHARED) | ((v) & DL_SHARED))
 
-inline static syn_sym_delinfo *
+inline static sen_sym_delinfo *
 delinfo_search(sen_sym *sym, sen_id id)
 {
   int i;
-  syn_sym_delinfo *di;
+  sen_sym_delinfo *di;
   for (i = (sym->header->curr_del2) & SEN_SYM_MDELINFOS;
        i != sym->header->curr_del;
        i = (i + 1) & SEN_SYM_MDELINFOS) {
@@ -361,7 +361,7 @@ delinfo_search(sen_sym *sym, sen_id id)
 }
 
 inline static sen_rc
-delinfo_turn_2(sen_sym *sym, syn_sym_delinfo *di)
+delinfo_turn_2(sen_sym *sym, sen_sym_delinfo *di)
 {
   sen_id d, *p = NULL;
   pat_node *ln, *dn;
@@ -403,7 +403,7 @@ delinfo_turn_2(sen_sym *sym, syn_sym_delinfo *di)
     /* debug */
     int j;
     sen_id dd;
-    syn_sym_delinfo *ddi;
+    sen_sym_delinfo *ddi;
     SEN_LOG(sen_log_debug, "failed to find d=%d", d);
     for (j = (sym->header->curr_del2 + 1) & SEN_SYM_MDELINFOS;
          j != sym->header->curr_del;
@@ -425,7 +425,7 @@ delinfo_turn_2(sen_sym *sym, syn_sym_delinfo *di)
 }
 
 inline static sen_rc
-delinfo_turn_3(sen_sym *sym, syn_sym_delinfo *di)
+delinfo_turn_3(sen_sym *sym, sen_sym_delinfo *di)
 {
   pat_node *dn;
   uint32_t size;
@@ -455,10 +455,10 @@ delinfo_turn_3(sen_sym *sym, syn_sym_delinfo *di)
   return sen_success;
 }
 
-inline static syn_sym_delinfo *
+inline static sen_sym_delinfo *
 delinfo_new(sen_sym *sym)
 {
-  syn_sym_delinfo *res = &sym->header->delinfos[sym->header->curr_del];
+  sen_sym_delinfo *res = &sym->header->delinfos[sym->header->curr_del];
   uint32_t n = (sym->header->curr_del + 1) & SEN_SYM_MDELINFOS;
   int gap = ((n + SEN_SYM_NDELINFOS - sym->header->curr_del2) & SEN_SYM_MDELINFOS)
             - (SEN_SYM_NDELINFOS / 2);
@@ -878,7 +878,7 @@ exit :
 inline static sen_rc
 _sen_sym_del(sen_sym *sym, const char *key, int shared)
 {
-  syn_sym_delinfo *di;
+  sen_sym_delinfo *di;
   uint8_t direction;
   pat_node *rn, *rn0 = NULL, *rno;
   int c, c0 = -1;
@@ -920,7 +920,7 @@ _sen_sym_del(sen_sym *sym, const char *key, int shared)
     }
     *p0 = otherside;
   } else {
-    syn_sym_delinfo *ldi = NULL, *ddi = NULL;
+    sen_sym_delinfo *ldi = NULL, *ddi = NULL;
     if (PAT_DEL(rn)) { ldi = delinfo_search(sym, r); }
     if (PAT_DEL(rn0)) { ddi = delinfo_search(sym, *p0); }
     if (ldi) {
