@@ -31,7 +31,7 @@ extern "C" {
 #define SEN_INDEX_DELIMITED                     0x0020
 #define SEN_INDEX_ENABLE_SUFFIX_SEARCH          0x0100
 #define SEN_INDEX_DISABLE_SUFFIX_SEARCH         0x0200
-#define SEN_INDEX_WITH_STORE                    0x1000
+#define SEN_INDEX_WITH_VGRAM                    0x1000
 #define SEN_INDEX_WITH_VACUUM                   0x8000
 
 /* 16 tokenizers can be registered */
@@ -161,8 +161,8 @@ typedef struct _sen_query sen_query;
 typedef struct _sen_logger_info sen_logger_info;
 typedef struct _sen_snip_mapping sen_snip_mapping;
 typedef struct _sen_records_heap sen_records_heap;
-typedef struct _sen_store sen_store;
-typedef struct _sen_store_buf sen_store_buf;
+typedef struct _sen_vgram sen_vgram;
+typedef struct _sen_vgram_buf sen_vgram_buf;
 typedef unsigned sen_id;
 
 #define SEN_ID_MAX 0x3fffffff
@@ -174,7 +174,7 @@ struct _sen_index {
   sen_sym *keys;
   sen_sym *lexicon;
   sen_inv *inv;
-  sen_store *store;
+  sen_vgram *vgram;
 };
 
 struct _sen_records {
