@@ -33,6 +33,8 @@ typedef struct {
 #define BUFFER_REC_AT(b,pos) ((buffer_rec *)(b) + (pos))
 
 int verbose;
+int check;
+int unlock;
 
 static inline void
 inv_inspect(sen_inv *inv, sen_sym *lexicon)
@@ -78,6 +80,7 @@ index_inspect(sen_index *i)
     fprintf(stderr, "sen_index_info failed (%d)", rc);
     return;
   }
+  printf("lock               %24u\n", *i->keys->lock);
   printf("key_size           %24d\n", key_size);
   printf("flags              %24d\n", flags);
   printf("initial_n_segments %24d\n", initial_n_segments);
@@ -89,6 +92,9 @@ index_inspect(sen_index *i)
   printf("inv_segment_size   %24u\n", inv_seg_size);
   printf("inv_chunk_size     %24u\n", inv_chunk_size);
   inv_inspect(i->inv, i->lexicon);
+  if (check) {
+    printf("n of errors in inv %24d\n", sen_inv_check(i->inv));
+  }
 }
 
 int
@@ -97,21 +103,26 @@ main(int argc, char **argv)
   int c;
   sen_index *i;
   verbose = 0;
+  check = 0;
+  unlock = 0;
 
   for (;;) {
-    c = getopt(argc, argv, "v");
+    c = getopt(argc, argv, "v:c:u");
     if (c == -1) { break; }
     if (c == 'v') { verbose = 1; }
+    if (c == 'c') { check = 1; }
+    if (c == 'u') { unlock = 1; }
   }
 
   if (optind >= argc) {
-    fputs("Usage: itest [-v] indexfile\n", stderr);
+    fputs("Usage: itest [-v] [-c] indexfile\n", stderr);
     return -1;
   }
   if (!(i = sen_index_open(argv[optind]))) {
     fprintf(stderr, "index open failed(%s)\n", argv[1]);
     return -1;
   }
+  if (unlock) { *i->keys->lock = 0; }
   index_inspect(i);
   return 0;
 }
